@@ -49,7 +49,8 @@ constructor call based on this information. Meaning, for the typical
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
